get_hitlist

Function get_hitlist 

pub fn get_hitlist(
    hitlist_path: &str,
    is_shuffle: bool,
    is_responsive: bool,
) -> (Vec<Address>, IpVersions, bool)
Get the hitlist from a file.

Supports plain fsdb files (with #fsdb header) based on the USC/ISI ANT hitlist format.

Arguments

  • hitlist_path - path to the hitlist file
  • is_shuffle - boolean whether the hitlist should be shuffled or not
  • is_responsive - whether the measurement gates probes behind a responsiveness check

Returns

  • A tuple containing the target addresses, the IP versions present, and whether the targets are a rank-major prefix hitlist (ISI + --responsive).

Panics

  • If the hitlist file cannot be opened.
  • If the hitlist is empty.