get_targets

Function get_targets 

pub fn get_targets(
    targets: &str,
    is_shuffle: bool,
) -> (Vec<Address>, IpVersions)
Build a hitlist from a comma-separated list of target addresses (e.g. from the --target CLI flag), as an alternative to a hitlist file. The targets are treated exactly like a hitlist containing those addresses.

Arguments

  • targets - comma-separated address list, e.g. “1.1.1.1” or “1.1.1.1,8.8.8.8”
  • is_shuffle - whether the resulting hitlist should be shuffled

Returns

  • A tuple of the parsed addresses and the IP versions present.