pub fn validate_ip_versions(
configurations: &[Configuration],
hitlist_versions: Option<IpVersions>,
m_type: MeasurementType,
) -> Result<IpVersions, String>Expand description
Validate the IP-version rules of a measurement and return the measured version(s).
- All hitlist targets must have an origin with a matching IP version
- tracemap does not support mixed IP version TODO
Arguments
configurations- the measurement configurationshitlist_versions- IP versions of the hitlist targets (Nonefor a live feed)m_type- the measurement type
Returns
The IP version(s) measured: those of the hitlist, or of the origins (live feed).