pub struct IpVersions {
pub has_v4: bool,
pub has_v6: bool,
}Expand description
IP versions present in a set of addresses (hitlist targets or origin sources).
Fields
has_v4: boolhas_v6: boolImplementations
Sourceimpl IpVersions
impl IpVersions
Sourcepub fn from_origins(configurations: &[Configuration]) -> Self
pub fn from_origins(configurations: &[Configuration]) -> Self
Collect the IP versions used by the (resolved) origin source addresses.
Sourcepub fn from_targets(targets: &[Address]) -> Self
pub fn from_targets(targets: &[Address]) -> Self
Collect the IP versions present in a list of target addresses.
Sourcepub fn file_token(&self) -> &'static str
pub fn file_token(&self) -> &'static str
Compact token for output filenames: “v4”, “v6”, or “mixed”.